@@ -33,13 +33,16 @@ from pathlib import Path
 from pprint import pformat
 from elastic_blast.constants import ElbCommand, ELB_DFLT_LOGLEVEL, ElbStatus
 from elastic_blast.constants import CSP, ELB_S3_PREFIX
-from elastic_blast.constants import ELB_METADATA_DIR, ELB_STATUS_SUCCESS, ELB_STATUS_FAILURE
+from elastic_blast.constants import ELB_METADATA_DIR, ELB_META_CONFIG_FILE
+from elastic_blast.constants import ELB_STATUS_SUCCESS, ELB_STATUS_FAILURE
 from elastic_blast.elasticblast import ElasticBlast
 from elastic_blast.aws import ElasticBlastAws
 from elastic_blast.elb_config import ElasticBlastConfig
 from elastic_blast.util import config_logging
+from elastic_blast.filehelper import open_for_read
+from elastic_blast import VERSION
 
-from elastic_blast.filehelper import thaw_config, upload_file_to_gcs, check_for_read
+from elastic_blast.filehelper import upload_file_to_gcs, check_for_read
 from elastic_blast.object_storage_utils import copy_file_to_s3
 
 
@@ -58,7 +61,7 @@ def copy_to_results_bucket_if_not_present(filename: str, bucket: str):
 
 def janitor(elb: ElasticBlast) -> None:
     """ ElasticBLAST Janitor function: cleans up ElasticBLAST resources """
-    st = elb.status()
+    st, _, _ = elb.check_status()
     results = elb.cfg.cluster.results
     cluster_name = elb.cfg.cluster.name
     if st == ElbStatus.SUCCESS:
@@ -71,10 +74,19 @@ def janitor(elb: ElasticBlast) -> None:
             copy_to_results_bucket_if_not_present(f.name, os.path.join(results, ELB_METADATA_DIR, ELB_STATUS_FAILURE))
         logging.debug(f'ElasticBLAST search with results on {results} has FAILED, deleting it (cluster name {cluster_name})')
         elb.delete()
+    elif st == ElbStatus.CREATING:
+        logging.debug(f'ElasticBLAST search on {results} is still being initialized (cluster name {cluster_name})')
+    elif st == ElbStatus.SUBMITTING:
+        logging.debug(f'ElasticBLAST search on {results} is performing job submission (cluster name {cluster_name})')
     elif st == ElbStatus.RUNNING:
         logging.debug(f'ElasticBLAST search with results on {results} is still running (cluster name {cluster_name})')
+    elif st == ElbStatus.DELETING:
+        logging.debug(f'ElasticBLAST search on {results} is being deleted (cluster name {cluster_name})')
     elif st == ElbStatus.UNKNOWN:
-        logging.warning(f'Unknown or expired ElasticBLAST search with results on {results} (cluster name {cluster_name})')
+        if elb.dry_run:
+            logging.warning(f'Unknown status on {results} because of dry-run option (cluster name {cluster_name})')
+        else:
+            logging.warning(f'Unknown or expired ElasticBLAST search with results on {results} (cluster name {cluster_name})')
 
 
 
@@ -84,36 +96,17 @@ def main():
     args = parser.parse_args()
     config_logging(args)
     try:
-        cf = thaw_config(args.results)
-        #logging.debug(f'Recovered configuration from {args.results}: {pformat(cf)}')
-        if 'aws' in cf:
-            logging.debug(f'AWS region: {cf["aws"]["region"]}')
-        else:
-            logging.debug(f'GCP project: {cf["gcp"]["project"]}')
-            logging.debug(f'GCP region: {cf["gcp"]["region"]}')
-            logging.debug(f'GCP zone: {cf["gcp"]["zone"]}')
-        logging.debug(f'BLAST program: {cf["blast"]["program"]}')
-        logging.debug(f'BLAST database: {cf["blast"]["db"]}')
-        logging.debug(f'ELB_CLUSTER_NAME: {cf["cluster"]["name"]}')
-        logging.debug(f'ELB_RESULTS: {cf["cluster"]["results"]}')
-        # FIXME: only AWS is supported right now
-        cfg = ElasticBlastConfig(aws_region = cf['aws']['region'],
-                                 program = cf['blast']['program'],
-                                 db = cf['blast']['db'],
-                                 queries = 'fake',
-                                 results = args.results,
-                                 cluster_name = cf['cluster']['name'],
-                                 task = ElbCommand.STATUS)
+        logging.info(f"ElasticBLAST Janitor {VERSION}")
 
-        if args.cluster_name:
-            cfg.cluster.name = args.cluster_name
-        if 'ELB_CLUSTER_NAME' in os.environ:
-            cfg.cluster.name = os.environ['ELB_CLUSTER_NAME']
-
-        logging.debug(f'{pformat(cfg.asdict())}')
+        cfg_uri = os.path.join(args.results, ELB_METADATA_DIR, ELB_META_CONFIG_FILE)
+        logging.debug(f"Loading {cfg_uri}")
+        with open_for_read(cfg_uri) as f:
+            cfg_json = f.read()
+        cfg = ElasticBlastConfig.from_json(cfg_json)
+        logging.debug(f'{cfg.to_json()}')
         cfg.validate(ElbCommand.STATUS)
+        eb = ElasticBlastAws(cfg, False)
 
-        eb = ElasticBlastAws(cfg)
         eb.dry_run = args.dry_run
         janitor(eb)
     except ClientError as ex:
@@ -127,7 +120,6 @@ def create_arg_parser():
     """ Create the command line options parser object for this script. """
     parser = argparse.ArgumentParser(description=DESC)
     parser.add_argument('--results', metavar='STR', type=str, help='Results bucket', required=True)
-    parser.add_argument('--cluster-name', metavar='STR', type=str, help='ElasticBLAST cluster name')
     parser.add_argument("--dry-run", action='store_true', help="Do not perform any actions")
     parser.add_argument("--logfile", default='stderr', type=str, help=f"Default: stderr")
     parser.add_argument("--loglevel", default=ELB_DFLT_LOGLEVEL,
